@@ -22,7 +22,7 @@ class Request(object):
         self.__connected_lock = None
         self.__protobuf_types = protobuf_types
         self.__parameter_tree = parameter_tree
-        self.__pool = ThreadPoolExecutor()
+        self.__pool = ThreadPoolExecutor(max_workers=1)
 
     def url(self):
         return self.__url
@@ -345,15 +345,17 @@ class Request(object):
             return ctypes.c_uint32(val).value
 
         for param in tree.params:
-            tree_hash += clip_u32(param.data_size + param.data_type + param.id + param.number_of_elements +
-                                  param.param_type + param.unit + param.group_id + param.permissions)
+            tree_hash += clip_u32(param.data_size + param.data_type + param.id + param.number_of_elements + \
+                         param.param_type + param.unit + param.group_id + param.permissions)
             for ch in param.path:
-                tree_hash = clip_u32(((tree_hash << 5) - tree_hash) + ord(ch))
+                tree_hash = clip_u32((tree_hash << 5) - tree_hash) + ord(ch)
                 tree_hash |= 0
 
             if hasattr(param, 'module_type'):
                 for ch in param.module_type:
-                    tree_hash = (clip_u32(tree_hash << 3) - tree_hash) + ord(ch)
+                    tree_hash = clip_u32((tree_hash << 3) - tree_hash) + ord(ch)
+
+        print(tree_hash)
 
         return tree_hash
 
@@ -375,13 +377,14 @@ class Request(object):
         handle = Request.__send(socket, protobuf_types.encode(param_tree_msg), protobuf_types)
 
         # encoding and sending data
-        return Request.__saveParameterTreeFile(handle)
+        return Request.__saveParameterTreeFile(handle, tree_hash.hash)
 
     @staticmethod
-    def __saveParameterTreeFile(parameter_tree):
+    def __saveParameterTreeFile(parameter_tree, hash):
         print('Saved parameter tree to the cache')
-        cache = Request.__hash(parameter_tree)
-        path = str(cache)
+        # cache = Request.__hash(parameter_tree)
+        # path = str(cache)
+        path = str(hash)
         data = parameter_tree.SerializeToString()
         text_file = open(path, "wb")
         text_file.write(data)
